.. _example-library:

Example library
---------------
This document contains the reference documentation of
a dummy library used in sphinx-codeautolink's documentation.
Besides providing valid hyperlink targets,
it also demonstrates the default autodoc integration.

.. automodule:: lib
